package taidegalleria;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * @author lainejee
 * @version 1.0 19.3.2025
 * |------------------------------------------------------------------------|
 * | Luokan nimi:   Taideteokset                        | Avustajat:        |
 * |-------------------------------------------------------------------------
 * | Vastuualueet:                                      |                   |
 * |                                                    | - Taideteos       |
 * |  - Pitää yllä varsinaista rekisteriä               |                   |
 * |    taideteoksista, eli osaa lisätä ja poistaa      |                   |
 * |    taideteoksen.                                   |                   |
 * |  - Lukee ja kirjoittaa taideteoksen tiedostoon.    |                   |
 * |  - Osaa etsiä ja lajitella.                        |                   |
 * |                                                    |                   |
 * |                                                    |                   |
 * |                                                    |                   |
 * |                                                    |                   |
 * |                                                    |                   |
 * |                                                    |                   |
 * |                                                    |                   |
 * |                                                    |                   |
 * |-------------------------------------------------------------------------
 */

public class Taideteokset {

    /** Taulukollinen taideteoksia. */
    private final Collection<Taideteos> alkiot = new ArrayList<Taideteos>();


    /**
     * Alustetaan taideteokset.
     */
    public Taideteokset() {
        // Ei tarvi tehdä mitään vielä.
    }


    /**
     * Lisää uuden taideteoksen tietokantaan.
     * @param teos lisättävä teos
     */
    public void lisaa(Taideteos teos) {
        alkiot.add(teos);
    }


    /**
     * Haetaan kaikki taiteilijan taideteokset.
     * @param tunnusId taiteilijan tunnus jolla taideteokset haetaan
     * @return tietorakenne jossa viiteet löydetteyihin taideteoksiin
     * @example
     * <pre name="test">
     * #import java.util.*;
     *
     *  Taideteokset teokset = new Taideteokset();
     *  Taideteos t001 = new Taideteos(2); teokset.lisaa(t001);
     *  Taideteos t003 = new Taideteos(1); teokset.lisaa(t003);
     *  Taideteos t007 = new Taideteos(2); teokset.lisaa(t007);
     *  Taideteos t050 = new Taideteos(1); teokset.lisaa(t050);
     *  Taideteos t030 = new Taideteos(2); teokset.lisaa(t030);
     *  Taideteos t012 = new Taideteos(5); teokset.lisaa(t012);
     *
     *  List<Taideteos> loytyneet;
     *  loytyneet = teokset.annaTaideteokset(3);
     *  loytyneet.size() === 0;
     *  loytyneet = teokset.annaTaideteokset(1);
     *  loytyneet.size() === 2;
     *  loytyneet.get(0) == t003 === true;
     *  loytyneet.get(1) == t050 === true;
     *  loytyneet = teokset.annaTaideteokset(5);
     *  loytyneet.size() === 1;
     *  loytyneet.get(0) == t012 === true;
     * </pre>
     */
    public List<Taideteos> annaTaideteokset(int tunnusId) {
        List<Taideteos> loydetyt = new ArrayList<Taideteos>();
        for (Taideteos teos : alkiot)
            if (teos.getTaiteilijaTunnus() == tunnusId) loydetyt.add(teos);
        return loydetyt;
    }


    /**
     * Testataan pääohjelmaa.
     * @param args ei käytössä
     */
    public static void main(String[] args) {
        Taideteokset suosikit = new Taideteokset();

        Taideteos t001 = new Taideteos();
        Taideteos t002 = new Taideteos();

        t001.rekisteroi();
        t001.vastaaTestiTaideteos(1);
        t002.rekisteroi();
        t002.vastaaTestiTaideteos(1);

        suosikit.lisaa(t001);
        suosikit.lisaa(t002);

        System.out.println("================== SUOSIKIT TESTI ==================");

        var taideteokset = suosikit.annaTaideteokset(1);

        for (Taideteos teos : taideteokset) {
            System.out.println(teos.getTaiteilijaTunnus() + " ");
            teos.tulosta(System.out);
        }


    }


}
